@@ -61,6 +61,7 @@ typedef struct {
 typedef struct {
 	GtkWidget   *image;
 	const char  *stock_id;
+	GIcon       *gicon;
 	GdkPixbuf   *pixbuf;
 	GtkIconSize  icon_size;
 } IconToAdd;
@@ -85,15 +86,6 @@ static void panel_load_menu_image_deferred (GtkWidget   *image_menu_item,
 static gboolean panel_menu_key_press_handler (GtkWidget   *widget,
 					      GdkEventKey *event);
 
-static inline gboolean
-panel_menu_have_icons (void)
-{	
-	return gconf_client_get_bool (
-			panel_gconf_get_client (),
-			"/desktop/gnome/interface/menus_have_icons",
-			NULL);
-}
-
 static inline gboolean
 desktop_is_home_dir (void)
 {	
@@ -189,51 +181,6 @@ menuitem_to_screen (GtkWidget *menuitem)
 	return gtk_window_get_screen (GTK_WINDOW (panel_widget->toplevel));
 }
 
-static void
-menus_have_icons_changed (GConfClient *client,
-			  guint        cnxn_id,
-			  GConfEntry  *entry,
-			  GtkWidget   *menu)
-{
-	GConfValue *value;
-	GList      *list, *l;
-	gboolean    have_icons = TRUE;
-
-	value = gconf_entry_get_value (entry);
-
-	if (value != NULL && value->type == GCONF_VALUE_BOOL)
-		have_icons = gconf_value_get_bool (value);
-
-	list = g_list_copy (GTK_MENU_SHELL (menu)->children);
-	for (l = list; l; l = l->next) {
-		GtkWidget *item = l->data;
-		GtkWidget *cur_image;
-		GtkWidget *image;
-
-		if (!GTK_IS_IMAGE_MENU_ITEM (item))
-			continue;
-
-		image = g_object_get_data (G_OBJECT (item), "Panel:Image");
-		if (!image)
-			continue;
-
-		cur_image = gtk_image_menu_item_get_image (
-					GTK_IMAGE_MENU_ITEM (item));
-
-		if (have_icons) {
-			if (cur_image != image) {
-				gtk_image_menu_item_set_image (
-					GTK_IMAGE_MENU_ITEM (item), image);
-				gtk_widget_show (image);
-			}
-		} else {
-			gtk_image_menu_item_set_image (
-				GTK_IMAGE_MENU_ITEM (item), NULL);
-		}
-	}
-	g_list_free (list);
-}
-
 static void
 reload_image_menu_items (void)
 {
@@ -278,10 +225,6 @@ panel_create_menu (void)
 	
 	retval = gtk_menu_new ();
 	gtk_widget_set_name (retval, "gnome-panel-main-menu");
-	
-	panel_gconf_notify_add_while_alive ("/desktop/gnome/interface/menus_have_icons",
-					    (GConfClientNotifyFunc) menus_have_icons_changed,
-					    G_OBJECT (retval));
 
 	g_signal_connect (retval, "key_press_event",
 			  G_CALLBACK (panel_menu_key_press_handler),
@@ -519,12 +462,17 @@ do_icons_to_add (void)
 
 		icons_to_add = g_list_delete_link (icons_to_add, icons_to_add);
 
-		if (icon_to_add->stock_id)
+		if (icon_to_add->stock_id) {
 			gtk_image_set_from_stock (
 				GTK_IMAGE (icon_to_add->image),
 				icon_to_add->stock_id,
 				icon_to_add->icon_size);
-		else {
+		} else if (icon_to_add->gicon) {
+			gtk_image_set_from_gicon (
+				GTK_IMAGE (icon_to_add->image),
+				icon_to_add->gicon,
+				icon_to_add->icon_size);
+		} else {
 			g_assert (icon_to_add->pixbuf);
 
 			gtk_image_set_from_pixbuf (
@@ -538,6 +486,8 @@ do_icons_to_add (void)
 			g_object_unref (icon_to_add->pixbuf);
 		}
 
+		if (icon_to_add->gicon)
+			g_object_unref (icon_to_add->gicon);
 		g_object_unref (icon_to_add->image);
 		g_free (icon_to_add);
 	}
@@ -571,7 +521,7 @@ load_icons_handler_again:
 		goto load_icons_handler_again;
 	}
 
-	if (icon->stock_id) {
+	if (icon->stock_id || icon->gicon) {
 		IconToAdd *icon_to_add;
 
 		icon_to_add            = g_new (IconToAdd, 1);
@@ -579,54 +529,10 @@ load_icons_handler_again:
 		icon_to_add->stock_id  = icon->stock_id;
 		icon_to_add->pixbuf    = NULL;
 		icon_to_add->icon_size = icon->icon_size;
-
-		icons_to_add = g_list_prepend (icons_to_add, icon_to_add);
-	} else if (icon->gicon) {
-		IconToAdd *icon_to_add;
-		char      *icon_name;
-		GdkPixbuf *pb;
-		int        icon_height = PANEL_DEFAULT_MENU_ICON_SIZE;
-
-		gtk_icon_size_lookup (icon->icon_size, NULL, &icon_height);
-
-		icon_name = panel_util_get_icon_name_from_g_icon (icon->gicon);
-
-		if (icon_name) {
-			pb = panel_make_menu_icon (icon->icon_theme,
-						   icon_name,
-						   icon->fallback_image,
-						   icon_height,
-						   &long_operation);
-			g_free (icon_name);
-		} else {
-			pb = panel_util_get_pixbuf_from_g_loadable_icon (icon->gicon, icon_height);
-			if (!pb && icon->fallback_image) {
-				pb = panel_make_menu_icon (icon->icon_theme,
-							   NULL,
-							   icon->fallback_image,
-							   icon_height,
-							   &long_operation);
-			}
-		}
-
-		if (!pb) {
-			icon_to_load_free (icon);
-			if (long_operation)
-				/* this may have been a long operation so jump
-				 * back to the main loop for a while */
-				return TRUE;
-			else
-				/* we didn't do anything long/hard, so just do
-				 * this again, this is fun, don't go back to
-				 * main loop */
-				goto load_icons_handler_again;
-		}
-
-		icon_to_add            = g_new (IconToAdd, 1);
-		icon_to_add->image     = g_object_ref (icon->pixmap);
-		icon_to_add->stock_id  = NULL;
-		icon_to_add->pixbuf    = pb;
-		icon_to_add->icon_size = icon->icon_size;
+		if (icon->gicon)
+			icon_to_add->gicon = g_object_ref (icon->gicon);
+		else
+			icon_to_add->gicon = NULL;
 
 		icons_to_add = g_list_prepend (icons_to_add, icon_to_add);
 	} else {
@@ -656,6 +562,7 @@ load_icons_handler_again:
 		icon_to_add            = g_new (IconToAdd, 1);
 		icon_to_add->image     = g_object_ref (icon->pixmap);
 		icon_to_add->stock_id  = NULL;
+		icon_to_add->gicon     = NULL;
 		icon_to_add->pixbuf    = pb;
 		icon_to_add->icon_size = icon->icon_size;
 
@@ -1282,9 +1189,8 @@ setup_menuitem (GtkWidget   *menuitem,
 					g_object_ref (image),
 					(GDestroyNotify) g_object_unref);
 		gtk_widget_show (image);
-		if (panel_menu_have_icons ())
-			gtk_image_menu_item_set_image (
-				GTK_IMAGE_MENU_ITEM (menuitem), image);
+		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem),
+					       image);
 	} else if (icon_size != GTK_ICON_SIZE_INVALID)
 		g_signal_connect (menuitem, "size_request",
 				  G_CALLBACK (image_menuitem_size_request),
@@ -1466,6 +1372,17 @@ create_fake_menu (GMenuTreeDirectory *directory)
 	return menu;
 }
 
+GtkWidget *
+panel_image_menu_item_new (void)
+{
+	GtkWidget *menuitem;
+
+	menuitem = gtk_image_menu_item_new ();
+	gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (menuitem),
+						   TRUE);
+	return menuitem;
+}
+
 static GtkWidget *
 create_submenu_entry (GtkWidget          *menu,
 		      GMenuTreeDirectory *directory)
@@ -1473,7 +1390,6 @@ create_submenu_entry (GtkWidget          *menu,
 	GtkWidget *menuitem;
 
 	menuitem = gtk_image_menu_item_new ();
-
 	panel_load_menu_image_deferred (menuitem,
 					panel_menu_icon_get_size (),
 					NULL, NULL,
@@ -1537,7 +1453,7 @@ create_menuitem (GtkWidget          *menu,
 {
 	GtkWidget  *menuitem;
 	
-	menuitem = gtk_image_menu_item_new ();
+	menuitem = panel_image_menu_item_new ();
 
 	g_object_set_data_full (G_OBJECT (menuitem),
 				"panel-menu-tree-entry",
@@ -1934,10 +1850,9 @@ panel_load_menu_image_deferred (GtkWidget   *image_menu_item,
 				"Panel:Image",
 				g_object_ref (image),
 				(GDestroyNotify) g_object_unref);
- 
-	if (panel_menu_have_icons ())
-		gtk_image_menu_item_set_image (
-			GTK_IMAGE_MENU_ITEM (image_menu_item), image);
+
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (image_menu_item),
+				       image);
 
 	g_signal_connect_data (image, "map",
 			       G_CALLBACK (image_menu_shown), icon,
