@@ -31,9 +31,9 @@
 #include <gtk/gtk.h>
 
 #include <libgnomeui/gnome-icon-entry.h>
-#include <libgnomeui/gnome-help.h>
 
 #include <libpanel-util/panel-keyfile.h>
+#include <libpanel-util/panel-show.h>
 
 #include "panel-ditem-editor.h"
 #include "panel-icon-names.h"
@@ -169,7 +169,7 @@ static guint ditem_edit_signals[LAST_SIGNAL] = { 0 };
 
 #define PANEL_DITEM_EDITOR_GET_PRIVATE(o)  (PANEL_DITEM_EDITOR (o)->priv)
 
-G_DEFINE_TYPE (PanelDItemEditor, panel_ditem_editor, GTK_TYPE_DIALOG);
+G_DEFINE_TYPE (PanelDItemEditor, panel_ditem_editor, GTK_TYPE_DIALOG)
 
 static void panel_ditem_editor_setup_ui (PanelDItemEditor *dialog);
 
@@ -1159,7 +1159,7 @@ type_combo_changed (PanelDItemEditor *dialog)
 		}
 		break;
 	case PANEL_DITEM_EDITOR_TYPE_TERMINAL_APPLICATION:
-		text = _("_Command:");
+		text = _("Comm_and:");
 		if (dialog->priv->combo_setuped) {
 			panel_key_file_set_string (dialog->priv->key_file,
 						   "Type", "Application");
@@ -1362,17 +1362,17 @@ panel_ditem_editor_save (PanelDItemEditor *dialog,
 	if (!dialog->priv->type_directory &&
 	    (const_buf == NULL || const_buf [0] == '\0')) {
 		PanelDItemEditorType  type;
-		char                 *error;
+		char                 *err;
 
 		type = panel_ditem_editor_get_item_type (dialog);
 
 		switch (type) {
 		case PANEL_DITEM_EDITOR_TYPE_APPLICATION:
 		case PANEL_DITEM_EDITOR_TYPE_TERMINAL_APPLICATION:
-			error = _("The command of the launcher is not set.");
+			err = _("The command of the launcher is not set.");
 			break;
 		case PANEL_DITEM_EDITOR_TYPE_LINK:
-			error = _("The location of the launcher is not set.");
+			err = _("The location of the launcher is not set.");
 			break;
 		default:
 			g_assert_not_reached ();
@@ -1381,8 +1381,7 @@ panel_ditem_editor_save (PanelDItemEditor *dialog,
 		if (report_errors)
 			g_signal_emit (G_OBJECT (dialog),
 				       ditem_edit_signals[ERROR_REPORTED], 0,
-				       _("Could not save launcher"),
-				       error);
+				       _("Could not save launcher"), err);
 		return FALSE;
 	}
 
@@ -1446,11 +1445,8 @@ response_cb (GtkDialog *dialog,
 
 	switch (response_id) {
 	case GTK_RESPONSE_HELP:
-		if (!gnome_help_display_desktop_on_screen (NULL, "user-guide",
-							   "user-guide",
-							   "gospanel-52",
-							   gtk_window_get_screen (GTK_WINDOW (dialog)),
-							   &error)) {
+		if (!panel_show_help (gtk_window_get_screen (GTK_WINDOW (dialog)),
+				      "user-guide", "gospanel-52", &error)) {
 			g_signal_emit (G_OBJECT (dialog),
 				       ditem_edit_signals[ERROR_REPORTED], 0,
 				       _("Could not display help document"),
