@@ -25,7 +25,7 @@
 #ifndef __PANEL_PROFILE_H__
 #define __PANEL_PROFILE_H__
 
-#include <glib/gmacros.h>
+#include <glib.h>
 #include <gdk/gdk.h>
 #include <gconf/gconf-client.h>
 
@@ -36,9 +36,7 @@
 
 G_BEGIN_DECLS
 
-void        panel_profile_load     (char *profile_name);
-const char *panel_profile_get_name (void);
-
+void panel_profile_load (void);
 
 const char    *panel_profile_get_toplevel_id    (PanelToplevel     *toplevel);
 PanelToplevel *panel_profile_get_toplevel_by_id (const char        *toplevel_id);
@@ -49,18 +47,19 @@ gboolean    panel_profile_get_show_program_list   (void);
 void        panel_profile_set_show_program_list   (gboolean show_program_list);
 gboolean    panel_profile_is_writable_show_program_list (void);
 gboolean    panel_profile_get_enable_program_list (void);
+gboolean    panel_profile_get_enable_autocompletion (void);
 
 
 void           panel_profile_add_to_list            (PanelGConfKeyType  type,
-						     char              *id);
+						     const char        *id);
 void           panel_profile_remove_from_list       (PanelGConfKeyType  type,
 						     const char        *id);
-gboolean       panel_profile_list_is_writable       (PanelGConfKeyType  type);
+gboolean       panel_profile_id_lists_are_writable  (void);
 void           panel_profile_create_toplevel        (GdkScreen         *screen);
 PanelToplevel *panel_profile_load_toplevel          (GConfClient       *client,
 						     const char        *profile_dir,
 						     PanelGConfKeyType  type,
-						     char              *toplevel_id);
+						     const char        *toplevel_id);
 void           panel_profile_delete_toplevel        (PanelToplevel     *toplevel);
 char          *panel_profile_prepare_object         (PanelObjectType    object_type,
 						     PanelToplevel     *toplevel,
@@ -73,9 +72,6 @@ char          *panel_profile_prepare_object_with_id (PanelObjectType    object_t
 void           panel_profile_delete_object          (AppletInfo        *applet_info);
 
 
-gboolean panel_profile_is_toplevel_list_writeable (void);
-
-
 void        panel_profile_set_toplevel_name           (PanelToplevel *toplevel,
 						       const char    *name);
 char       *panel_profile_get_toplevel_name           (PanelToplevel *toplevel);
@@ -113,8 +109,6 @@ gboolean    panel_profile_get_toplevel_enable_arrows  (PanelToplevel *toplevel);
 gboolean    panel_profile_is_writable_toplevel_enable_arrows (PanelToplevel *toplevel);
 
 /* We don't set this in the panel, so there is no set accessor */
-gboolean    panel_profile_get_toplevel_locked_down    (PanelToplevel *toplevel);
-
 void        panel_profile_set_background_type         (PanelToplevel       *toplevel,
 						       PanelBackgroundType  background_type);
 PanelBackgroundType
@@ -127,10 +121,10 @@ void        panel_profile_get_background_color        (PanelToplevel       *topl
 						       PanelColor          *color);
 gboolean    panel_profile_is_writable_background_color (PanelToplevel       *toplevel);
 
-void        panel_profile_set_background_pango_color  (PanelToplevel       *toplevel,
-						       PangoColor          *pango_color);
-void        panel_profile_get_background_pango_color  (PanelToplevel       *toplevel,
-						       PangoColor          *pango_color);
+void        panel_profile_set_background_gdk_color    (PanelToplevel       *toplevel,
+						       GdkColor            *gdk_color);
+void        panel_profile_get_background_gdk_color    (PanelToplevel       *toplevel,
+						       GdkColor            *gdk_color);
 
 void        panel_profile_set_background_opacity      (PanelToplevel       *toplevel,
 						       guint16              opacity);
@@ -185,12 +179,6 @@ gboolean    panel_profile_map_object_type_string      (const char            *st
 /* all keys relevant to moving are writable */
 gboolean    panel_profile_can_be_moved_freely         (PanelToplevel *toplevel);
 
-/* Lockdown stuff */
-gboolean    panel_profile_get_inhibit_command_line    (void);
-gboolean    panel_profile_get_inhibit_force_quit      (void);
-gboolean    panel_profile_get_locked_down             (void);
-GSList     *panel_profile_get_disabled_applets        (void);
-
 G_END_DECLS
 
 #endif /* __PANEL_PROFILE_H__ */
